netapp_ontap.models.vsi_on_san_new_igroups API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.vsi_on_san_new_igroups`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VsiOnSanNewIgroupsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VsiOnSanNewIgroups object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `initiators GET POST PATCH`

    The initiators field of the vsi_on_san_new_igroups.

  `name POST PATCH`

    The name of the new initiator group.

  `protocol POST PATCH`

    The protocol of the new initiator group.

    Valid choices:

    - fcp
    - iscsi
    - mixed